==> ec2-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnSpotFleetProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::SpotFleet`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:13:21.643Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSpotFleetProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html#cfn-ec2-spotfleet-spotfleetrequestconfigdata
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Object getSpotFleetRequestConfigData();

    /**
     * @return a {@link Builder} of {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.Object _spotFleetRequestConfigData;

        /**
         * Sets the value of SpotFleetRequestConfigData
         * @param value `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withSpotFleetRequestConfigData(final software.amazon.awscdk.core.IResolvable value) {
            this._spotFleetRequestConfigData = java.util.Objects.requireNonNull(value, "spotFleetRequestConfigData is required");
            return this;
        }
        /**
         * Sets the value of SpotFleetRequestConfigData
         * @param value `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withSpotFleetRequestConfigData(final software.amazon.awscdk.services.ec2.CfnSpotFleet.SpotFleetRequestConfigDataProperty value) {
            this._spotFleetRequestConfigData = java.util.Objects.requireNonNull(value, "spotFleetRequestConfigData is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSpotFleetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnSpotFleetProps build() {
            return new CfnSpotFleetProps() {
                private final java.lang.Object $spotFleetRequestConfigData = java.util.Objects.requireNonNull(_spotFleetRequestConfigData, "spotFleetRequestConfigData is required");

                @Override
                public java.lang.Object getSpotFleetRequestConfigData() {
                    return this.$spotFleetRequestConfigData;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("spotFleetRequestConfigData", om.valueToTree(this.getSpotFleetRequestConfigData()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnSpotFleetProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html#cfn-ec2-spotfleet-spotfleetrequestconfigdata
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.Object getSpotFleetRequestConfigData() {
            return this.jsiiGet("spotFleetRequestConfigData", java.lang.Object.class);
        }
    }
}

==> ec2-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnSpotFleetProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::SpotFleet`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:06:47.559Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnSpotFleetProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html#cfn-ec2-spotfleet-spotfleetrequestconfigdata
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getSpotFleetRequestConfigData();

    /**
     * @return a {@link Builder} of {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.Object _spotFleetRequestConfigData;

        /**
         * Sets the value of SpotFleetRequestConfigData
         * @param value `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withSpotFleetRequestConfigData(final software.amazon.awscdk.core.IResolvable value) {
            this._spotFleetRequestConfigData = java.util.Objects.requireNonNull(value, "spotFleetRequestConfigData is required");
            return this;
        }
        /**
         * Sets the value of SpotFleetRequestConfigData
         * @param value `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withSpotFleetRequestConfigData(final software.amazon.awscdk.services.ec2.CfnSpotFleet.SpotFleetRequestConfigDataProperty value) {
            this._spotFleetRequestConfigData = java.util.Objects.requireNonNull(value, "spotFleetRequestConfigData is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSpotFleetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnSpotFleetProps build() {
            return new CfnSpotFleetProps() {
                private final java.lang.Object $spotFleetRequestConfigData = java.util.Objects.requireNonNull(_spotFleetRequestConfigData, "spotFleetRequestConfigData is required");

                @Override
                public java.lang.Object getSpotFleetRequestConfigData() {
                    return this.$spotFleetRequestConfigData;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("spotFleetRequestConfigData", om.valueToTree(this.getSpotFleetRequestConfigData()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnSpotFleetProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html#cfn-ec2-spotfleet-spotfleetrequestconfigdata
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.Object getSpotFleetRequestConfigData() {
            return this.jsiiGet("spotFleetRequestConfigData", java.lang.Object.class);
        }
    }
}
